summaryrefslogtreecommitdiffstats
path: root/konq-plugins/domtreeviewer/domtreewindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'konq-plugins/domtreeviewer/domtreewindow.h')
-rw-r--r--konq-plugins/domtreeviewer/domtreewindow.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/konq-plugins/domtreeviewer/domtreewindow.h b/konq-plugins/domtreeviewer/domtreewindow.h
index c138446..2715eb5 100644
--- a/konq-plugins/domtreeviewer/domtreewindow.h
+++ b/konq-plugins/domtreeviewer/domtreewindow.h
@@ -42,7 +42,7 @@ class DOMTreeView;
class PluginDomtreeviewer;
class KAction;
-class KConfig;
+class TDEConfig;
class KPrinter;
class KURL;
class KCommandHistory;
@@ -113,7 +113,7 @@ public:
/**
* Returns the config object for this plugin.
*/
- KConfig *config() const { return _config; }
+ TDEConfig *config() const { return _config; }
/** returns the attribute delete action */
KAction *deleteAttributeAction() const { return del_attr; }
@@ -144,14 +144,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig *);
+ void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig *);
+ void readProperties(TDEConfig *);
private slots:
@@ -185,7 +185,7 @@ private:
KCommandHistory *m_commandHistory;
TQPopupMenu *infopanel_ctx;
TQPopupMenu *domtree_ctx;
- KConfig *_config;
+ TDEConfig *_config;
KAction *del_tree, *del_attr;
@@ -144,14 +144,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties